/// <reference types="react" />
import * as monaco from 'monaco-editor';
import { DecorationsSource, DefinitionSource, DiagnosticsSource, EditorAction, HoverSource } from './utils';
import { EnrichedLanguageService } from './enriched-language-service';
import { GraphQLError, GraphQLSchema } from 'graphql';
export declare type SchemaEditorApi = {
    jumpToType(typeName: string): void;
    jumpToField(typeName: string, fieldName: string): void;
    deselect(): void;
};
export declare type SchemaServicesOptions = {
    schema?: string;
    hoverProviders?: HoverSource[];
    definitionProviders?: DefinitionSource[];
    diagnosticsProviders?: DiagnosticsSource[];
    decorationsProviders?: DecorationsSource[];
    actions?: EditorAction[];
    onBlur?: (value: string) => void;
    onLanguageServiceReady?: (languageService: EnrichedLanguageService) => void;
    onSchemaChange?: (schema: GraphQLSchema, sdl: string) => void;
    onSchemaError?: (errors: [GraphQLError], sdl: string, languageService: EnrichedLanguageService) => void;
    sharedLanguageService?: EnrichedLanguageService;
    keyboardShortcuts?: (editorInstance: monaco.editor.IStandaloneCodeEditor, monacoInstance: typeof monaco) => monaco.editor.IActionDescriptor[];
};
export declare const useSchemaServices: (options?: SchemaServicesOptions) => {
    setEditor: import("react").Dispatch<import("react").SetStateAction<monaco.editor.IStandaloneCodeEditor | null>>;
    setMonaco: import("react").Dispatch<import("react").SetStateAction<typeof monaco | null>>;
    editorRef: monaco.editor.IStandaloneCodeEditor | null;
    monacoRef: typeof monaco | null;
    languageService: EnrichedLanguageService;
    setSchema: (newValue: string) => Promise<GraphQLSchema | null>;
    editorApi: SchemaEditorApi;
};
